@@ -47,18 +47,12 @@ void make_vert_to_edge_maps (const std::vector <std::string> &from,
 } // end namespace run_sp
 
 Rcpp::NumericMatrix rcpp_get_sp_dists (const Rcpp::DataFrame graph,
-        const Rcpp::DataFrame vert_map_in,
-        std::vector <int> fromi,
-        std::vector <int> toi,
-        const std::string& heap_type);
-
-Rcpp::NumericMatrix rcpp_get_sp_dists_par (const Rcpp::DataFrame graph,
         const Rcpp::DataFrame vert_map_in,
         Rcpp::IntegerVector fromi,
         Rcpp::IntegerVector toi,
         const std::string& heap_type);
 
-Rcpp::NumericMatrix rcpp_get_sp_dists (const Rcpp::DataFrame graph,
+Rcpp::NumericMatrix rcpp_get_sp_dists_par (const Rcpp::DataFrame graph,
         const Rcpp::DataFrame vert_map_in,
         Rcpp::IntegerVector fromi,
         Rcpp::IntegerVector toi,
